@@ -10,7 +10,7 @@ use warnings;
 
 use utf8;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -176,6 +176,14 @@ to call from a C<DESTROY> method or C<END> block.
 
 The following methods are common to all protocol instances:
 
+=head2 sleep
+
+   $protocol->sleep( $secs )->get
+
+Causes a fixed delay, given in (fractional) seconds. Adapter module authors
+should attempt to perform this delay concurrently, overlapping IO with other
+operations where possible.
+
 =head2 configure
 
    $protocol->configure( %args )->get
