@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::Chip::Adapter );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -124,13 +124,16 @@ that invocation.
  $exp = $adapter->expect_write_no_ss( $bytes )
 
 The returned expectation object allows the test script to specify what such an
-invocation should return.
+invocation should return or throw.
 
  $exp->returns( $bytes_in )
+ $exp->fails( $failure )
 
 =cut
 
 my %METHODS = (
+   sleep           => [ undef,
+                        [qw( GPIO SPI I2C )] ],
    write_gpios     => [ sub { my ( $v ) = @_; join ",", map { $v->{$_} ? $_ : "!$_" } sort keys %$v },
                         [qw( GPIO SPI I2C )] ],
    read_gpios      => [ sub { my ( $v ) = @_; join ",", @$v },
@@ -161,7 +164,7 @@ foreach my $method ( keys %METHODS ) {
       my $self = shift;
       @_ = $canonicalise->( @_ ) if $canonicalise;
 
-      push @{ $self->{expect} }, my $e = bless [ $method, [ @_ ], 0, [] ],
+      push @{ $self->{expect} }, my $e = bless [ $method, [ @_ ], 0 ],
          "Test::Device::Chip::Adapter::_Expectation";
 
       return $e;
@@ -182,7 +185,7 @@ foreach my $method ( keys %METHODS ) {
          # TODO: reflect this in test result
          croak "Unexpected call to ->$method(${\ _stringify_args @args })";
 
-      return Future->done( $e->return );
+      return $e->future;
    };
 
    no strict 'refs';
@@ -234,10 +237,11 @@ package
 use List::Util qw( all );
 
 use constant {
-   METHOD => 0,
-   ARGS   => 1,
-   CALLED => 2,
-   RETURN => 3,
+   METHOD  => 0,
+   ARGS    => 1,
+   CALLED  => 2,
+   RETURN  => 3,
+   FAILURE => 4,
 };
 
 sub complete
@@ -267,11 +271,25 @@ sub check
    $builder->ok( $self->[CALLED], $self->[METHOD] );
 }
 
-sub return { @{ $_[0]->[3] } }
 sub returns
 {
    my $self = shift;
-   $self->[3] = [ @_ ];
+   $self->[FAILURE] and die "Cannot set a return value for a failing expectation\n";
+   $self->[RETURN] = [ @_ ];
+}
+
+sub fails
+{
+   my $self = shift;
+   $self->[RETURN] and die "Cannot set a failure for a returning expectation\n";
+   $self->[FAILURE] = [ @_ ];
+}
+
+sub future
+{
+   my $self = shift;
+   $self->[FAILURE] ? Future->fail( @{ $self->[FAILURE] } )
+                    : Future->done( @{ $self->[RETURN] } )
 }
 
 =head1 TODO
